<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * @package block_eledia_coursewizard
 * @author Matthias Schwabe <support@eledia.de>
 * @copyright 2013 & 2014 eLeDia GmbH
 * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
 */

require_once('../../config.php');

defined('MOODLE_INTERNAL') || die;

require_once($CFG->dirroot . '/course/lib.php');
require_once($CFG->dirroot . '/blocks/eledia_coursewizard/createcourse_form.php');
require_once(dirname(__FILE__) . '/adduser_form.php');
require_once($CFG->dirroot.'/user/profile/lib.php');

$id  = optional_param('id', 0, PARAM_INT);  // Course id.
$pageparams = array('id' => $id);
$PAGE->set_url('/blocks/eledia_coursewizard/adduser.php', $pageparams);

require_login();
$context = context_course::instance($id);
$PAGE->set_context($context);
$user = new StdClass();
$config = get_config('block_eledia_coursewizard');

$editform = new coursewizard_add_users_form(null, array('user' => $user));

if ($data = $editform->get_data()) {
    $cid = $data->id;

    if ($data->email != '') {

        $config = get_config('block_eledia_coursewizard');

        $usernames = $data->email;
        $usernames = str_replace("\n", " ", $usernames);
        $usernames = str_replace("\r", " ", $usernames);
        $usernames = str_replace(" ", "", $usernames);
        $usernames = explode(",", $usernames);

        $invalidemails = Array();  // Array for invalid e-mail addresses.

        foreach ($usernames as $username) {

            if (validate_email($username)) {

                $contact = get_admin();
                $uname = $DB->get_record('user', array('email' => $username));
                $site = $DB->get_record('course', array('id' => 1));
                $courseurl = $CFG->wwwroot."/course/view.php?id=".$cid;

                // New user => create, enrol and mail.
                if (empty($uname)) {

                    $passhash = md5($username.rand(1, 1000));
                    $password = substr($passhash, 0, 12);

                    // Create new user.
                    $newuser = create_user_record($username, $password, 'email');
                    $newuser->email = $username;
                    $newuser->emailstop = 0;
                    $newuser->maildisplay = 2;
                    $newuser->policyagreed = 0;

                    if (!empty($config->syncfields)) {

                        profile_load_data($USER);
                        profile_load_data($newuser);

                        $userfields = explode(',', $config->syncfields);

                        foreach ($userfields as $field) {
                            if (isset($USER->{$field})) {
                                $newuser->{$field} = $USER->{$field};
                            }
                            $profilefield = 'profile_field_'.$field;
                            if (isset($USER->$profilefield )) {
                                $newuser->$profilefield = $USER->$profilefield ;
                            }
                        }
                        profile_save_data($newuser);
                    }

                    $DB->update_record('user', $newuser);
                    set_user_preference('auth_forcepasswordchange', 1, $newuser->id);

                    enrol_try_internal_enrol($cid, $newuser->id, 5);  // Enrol into new course.

				 // E-Mail to new user.
                    $mailuser = new stdClass();  // Dummy user because email_to_user needs a user.
                    $mailuser->email = $username;
                    $mailuser->id = $newuser->id;

                    $mailuser->firstname = ' ';
                    $mailuser->lastname = ' ';
                    $mailuser->firstnamephonetic = ' ';
                    $mailuser->lastnamephonetic = ' ';
                    $mailuser->middlename = ' ';
                    $mailuser->alternatename = ' ';

                    $content = $config->mailcontent."\n\n";
                    $content .= "Moodle URL: ".$CFG->wwwroot."\n";
                    $content .= "Username: ".$username."\n";
                    $content .= "Password: ".$password;

                    email_to_user($mailuser, $contact, $config->mailsubject, strip_tags($content), $content);

                } else {  // Existing user => enrol and mail.

                    enrol_try_internal_enrol($cid, $uname->id, 5);  // Enrol into new course.

                    $content = $config->mailcontent_notnew."\n\n";
                    $content .= "Moodle URL: ".$CFG->wwwroot."\n";
                    $content .= "Moodle course: ".$CFG->wwwroot."/course/view.php?id=".$cid."\n";
                    email_to_user($uname, $contact, $config->mailsubject_notnew, strip_tags($content), $content);
                }
            } else {
                $invalidemails[] = $username;
            }
        }
    }
    if (!empty($invalidemails)) {
        foreach ($invalidemails as $invalidemail) {
            echo get_string('invalidemail', 'block_eledia_coursewizard', $invalidemail);
        }
    } else {
        $url = $CFG->wwwroot."/enrol/users.php?id=".$cid;
        redirect($url);
    }
}

$course = $DB->get_record('course', array('id' => $id), '*', MUST_EXIST);

$straddnewuser = get_string('addusers_button', 'block_eledia_coursewizard');
$stradministration = get_string("administration");
$strcategories = get_string("categories");

$PAGE->navbar->add($stradministration, new moodle_url('/admin/index.php'));
$PAGE->navbar->add($strcategories, new moodle_url('/course/index.php'));
$PAGE->navbar->add($course->shortname, $CFG->wwwroot.'/course/view.php?id='.$id);
$PAGE->navbar->add($straddnewuser);

$title = $course->shortname.': '.$straddnewuser;
$fullname = $course->fullname;
$PAGE->set_title($title);
$PAGE->set_heading($fullname);

echo $OUTPUT->header();
$editform->display();
echo $OUTPUT->footer();
